@@ -5,6 +5,7 @@ from gwaslab.Log import Log
 from gwaslab.CommonData import get_chr_to_number
 from gwaslab.CommonData import get_number_to_chr
 from gwaslab.CommonData import get_chr_to_NC
+from gwaslab.CommonData import gtf_to_protein_coding
 from gwaslab.download import check_and_download
 from gwaslab.gwascatalog import gwascatalog_trait
 from pyensembl import EnsemblRelease
@@ -23,6 +24,7 @@ def getsig(insumstats,
            chrom,
            pos,
            p,
+           scaled=False,
            windowsizekb=500,
            sig_level=5e-8,
            log=Log(),
@@ -140,11 +142,11 @@ def closest_gene(x,data,chrom="CHR",pos="POS",maxiter=20000,step=50,source="ense
         elif source=="refseq":
             contig = get_number_to_chr()[x[chrom]]
             contig = get_chr_to_NC(build=build)[contig]
-        
+            # for refseq , gene names are stored as gene_id, using gene_ids_at_locus instead
+            data.gene_names_at_locus = data.gene_ids_at_locus
         position = int(x[pos])
         # query
         gene = data.gene_names_at_locus(contig=contig, position=position)
-        
         if len(gene)==0:
             # if not in any gene
             i=0
@@ -166,28 +168,28 @@ def closest_gene(x,data,chrom="CHR",pos="POS",maxiter=20000,step=50,source="ense
                         gene_u = data.gene_names_at_locus(contig=contig, position=position-distance-j)
                         gene_d = data.gene_names_at_locus(contig=contig, position=position+distance+j)
                         if len(gene_u)>0:
-                            return -distance-j,",".join(gene_u)
+                            return -distance-j,",".join(gene_u).strip(",")
                         elif len(gene_d)>0:
-                            return distance+j,",".join(gene_d)
+                            return distance+j,",".join(gene_d).strip(",")
                 elif len(gene_u)>0:                    
                     # if found gene uptream
                     distance = (i-1)*step
                     for j in range(0,step,1):
                         gene_u2 = data.gene_names_at_locus(contig=contig, position=position-distance-j)
                         if len(gene_u2)>0:
-                            return -distance-j,",".join(gene_u)
+                            return -distance-j,",".join(gene_u).strip(",")
                 elif len(gene_d)>0:
                     # if found gene downstream
                     distance = (i-1)*step
                     for j in range(0,step,1):
                         gene_d2 = data.gene_names_at_locus(contig=contig, position=position+distance+j)
                         if len(gene_d2)>0:
-                            return distance+j,",".join(gene_d)
+                            return distance+j,",".join(gene_d).strip(",")
                 i+=1
                 # increase i by 1
             return distance,"intergenic"
         else:
-            return 0,",".join(gene)
+            return 0,",".join(gene).strip(",")
 
 
 def annogene(
@@ -207,17 +209,19 @@ def annogene(
     if source == "ensembl":
         if build=="19":
             #data = EnsemblRelease(75)
-            if verbose:log.write(" -Assigning Gene name using Ensembl Release hg19")
+            if verbose:log.write(" -Assigning Gene name using ensembl_hg19_gtf for protein coding genes")
             #zcat Homo_sapiens.GRCh37.75.gtf.gz| 
             #grep -E 'processed_transcript|protein_coding|_gene' 
             #| gzip >Homo_sapiens.GRCh37.75.processed.chr.gtf.gz     
             
-            gtf_path = check_and_download("ensembl_hg19_gtf_protein_coding")
+            #gtf_path = check_and_download("ensembl_hg19_gtf_protein_coding")
+            gtf_path = check_and_download("ensembl_hg19_gtf")
+            gtf_path = gtf_to_protein_coding(gtf_path,log=log,verbose=verbose)
             gtf_db_path = gtf_path[:-2]+"db"
             
             data = Genome(
                 reference_name='GRCh37',
-                annotation_name='hg19_gene',
+                annotation_name='Ensembl',
                 gtf_path_or_url=gtf_path)
             if path.isfile(gtf_db_path) is False:
                 data.index()
@@ -225,12 +229,14 @@ def annogene(
                 list(output.apply(lambda x:closest_gene(x,data=data,source=source), axis=1)), 
                 index=output.index).values
         elif build=="38":
-            if verbose:log.write(" -Assigning Gene name using built-in Ensembl Release hg38")
-            gtf_path = check_and_download("ensembl_hg38_gtf_protein_coding")
+            if verbose:log.write(" -Assigning Gene name using ensembl_hg38_gtf for protein coding genes")
+            #gtf_path = check_and_download("ensembl_hg38_gtf_protein_coding")
+            gtf_path = check_and_download("ensembl_hg38_gtf")
+            gtf_path = gtf_to_protein_coding(gtf_path,log=log,verbose=verbose)
             gtf_db_path = gtf_path[:-2]+"db"
             data = Genome(
                 reference_name='GRCh38',
-                annotation_name='hg38_gene',
+                annotation_name='Ensembl',
                 gtf_path_or_url=gtf_path)
             if path.isfile(gtf_db_path) is False:
                 data.index()
@@ -240,12 +246,14 @@ def annogene(
     
     if source == "refseq":
         if build=="19":
-            if verbose:log.write(" -Assigning Gene name using NCBI refseq latest GRCh37")
-            gtf_path = check_and_download("refseq_hg19_gtf_protein_coding")
+            if verbose:log.write(" -Assigning Gene name using NCBI refseq latest GRCh37 for protein coding genes")
+            #gtf_path = check_and_download("refseq_hg19_gtf_protein_coding")
+            gtf_path = check_and_download("refseq_hg19_gtf")
+            gtf_path = gtf_to_protein_coding(gtf_path,log=log,verbose=verbose)
             gtf_db_path = gtf_path[:-2]+"db"
             data = Genome(
                 reference_name='GRCh37',
-                annotation_name='hg19_gene',
+                annotation_name='Refseq',
                 gtf_path_or_url=gtf_path)
             if path.isfile(gtf_db_path) is False:
                 data.index()
@@ -253,12 +261,14 @@ def annogene(
                 list(output.apply(lambda x:closest_gene(x,data=data,source=source,build=build), axis=1)), 
                 index=output.index).values
         elif build=="38":
-            if verbose:log.write(" -Assigning Gene name using built-in NCBI refseq latest GRCh38")
-            gtf_path = check_and_download("refseq_hg38_gtf_protein_coding")
+            if verbose:log.write(" -Assigning Gene name using NCBI refseq latest GRCh38 for protein coding genes")
+            #gtf_path = check_and_download("refseq_hg38_gtf_protein_coding")
+            gtf_path = check_and_download("refseq_hg38_gtf")
+            gtf_path = gtf_to_protein_coding(gtf_path,log=log,verbose=verbose)
             gtf_db_path = gtf_path[:-2]+"db"
             data = Genome(
                 reference_name='GRCh38',
-                annotation_name='hg38_gene',
+                annotation_name='Refseq',
                 gtf_path_or_url=gtf_path)
             if path.isfile(gtf_db_path) is False:
                 data.index()
